==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/DataLegendSummaryColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendSeriesValueInfoDescriptionMetadata } from "./DataLegendSeriesValueInfoDescriptionMetadata";
import { DataLegendSummaryColumnDescription } from "./DataLegendSummaryColumnDescription";
/**
 * @hidden
 */
var DataLegendSummaryColumnDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DataLegendSummaryColumnDescriptionMetadata, _super);
    function DataLegendSummaryColumnDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataLegendSummaryColumnDescriptionMetadata.b = function (a) {
        if (DataLegendSummaryColumnDescriptionMetadata.a == null) {
            DataLegendSummaryColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataLegendSummaryColumnDescriptionMetadata.c(DataLegendSummaryColumnDescriptionMetadata.a);
        }
        if (a.g(DataLegendSummaryColumnDescriptionMetadata.a)) {
            return;
        }
        a.s(DataLegendSummaryColumnDescriptionMetadata.a);
    };
    DataLegendSummaryColumnDescriptionMetadata.c = function (a) {
        DataLegendSeriesValueInfoDescriptionMetadata.c(a);
    };
    DataLegendSummaryColumnDescriptionMetadata.d = function (a) {
        DataLegendSummaryColumnDescriptionMetadata.b(a);
        a.u("DataLegendSummaryColumn", function () { return new DataLegendSummaryColumnDescription(); });
        a.t("DataLegendSummaryColumn", DataLegendSummaryColumnDescriptionMetadata.a);
    };
    DataLegendSummaryColumnDescriptionMetadata.$t = markType(DataLegendSummaryColumnDescriptionMetadata, 'DataLegendSummaryColumnDescriptionMetadata');
    DataLegendSummaryColumnDescriptionMetadata.a = null;
    return DataLegendSummaryColumnDescriptionMetadata;
}(Base));
export { DataLegendSummaryColumnDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/DataLegendSummaryColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendSeriesValueInfoDescriptionMetadata } from "./DataLegendSeriesValueInfoDescriptionMetadata";
import { DataLegendSummaryColumnDescription } from "./DataLegendSummaryColumnDescription";
/**
 * @hidden
 */
var DataLegendSummaryColumnDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DataLegendSummaryColumnDescriptionMetadata, _super);
    function DataLegendSummaryColumnDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataLegendSummaryColumnDescriptionMetadata.b = function (a) {
        if (DataLegendSummaryColumnDescriptionMetadata.a == null) {
            DataLegendSummaryColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataLegendSummaryColumnDescriptionMetadata.c(DataLegendSummaryColumnDescriptionMetadata.a);
        }
        if (a.j(DataLegendSummaryColumnDescriptionMetadata.a)) {
            return;
        }
        a.y(DataLegendSummaryColumnDescriptionMetadata.a);
    };
    DataLegendSummaryColumnDescriptionMetadata.c = function (a) {
        DataLegendSeriesValueInfoDescriptionMetadata.c(a);
    };
    DataLegendSummaryColumnDescriptionMetadata.d = function (a) {
        DataLegendSummaryColumnDescriptionMetadata.b(a);
        a.aa("DataLegendSummaryColumn", function () { return new DataLegendSummaryColumnDescription(); });
        a.z("DataLegendSummaryColumn", DataLegendSummaryColumnDescriptionMetadata.a);
    };
    DataLegendSummaryColumnDescriptionMetadata.$t = markType(DataLegendSummaryColumnDescriptionMetadata, 'DataLegendSummaryColumnDescriptionMetadata');
    DataLegendSummaryColumnDescriptionMetadata.a = null;
    return DataLegendSummaryColumnDescriptionMetadata;
}(Base));
export { DataLegendSummaryColumnDescriptionMetadata };
